==> react-native-snap-carousel-3.7.3.tgz: package/ISSUE_TEMPLATE.md <==
<!--
  MAKE SURE TO READ AND FOLLOW THIS TEMPLATE CLOSELY OR YOUR ISSUE WILL BE CLOSED WITHOUT NOTICE
-->

### Is this a bug report, a feature request, or a question?

(Write your answer here.)

<!--
  If you answered "Bug report":

    We expect you to produce a high-quality bug report since putting care into your report helps us fix the issue faster.
    For bug reports, it is REQUIRED to fill the rest of this template, or the issue will be closed.

  If you answered "Feature request" or "Question":

    Make sure to describe as precisely as possible the feature you'd like to see implemented or the question you'd like to see answered.
    When relevant, provide visual examples (screenshots, screencasts, diagrams...).
    You can ignore the next steps as long as you've made sure that your description is as clear, thorough and illustrated as possible.
-->

### Have you followed the required steps before opening a bug report?

(Check the step you've followed - replace the space character between the square brackets (`[]`) by an `x`.)

- [ ] I have read [the guidelines regarding bug report](https://github.com/archriss/react-native-snap-carousel/blob/master/CONTRIBUTING.md).
- [ ] I have reviewed [the documentation](https://github.com/archriss/react-native-snap-carousel/blob/master/README.md) in its entirety, including the dedicated documentations :books:.
- [ ] I have searched for [existing issues](https://github.com/archriss/react-native-snap-carousel/issues) and made sure that the problem hasn't already been reported.
- [ ] I am using [the latest plugin version](https://github.com/archriss/react-native-snap-carousel/releases).
- [ ] I am following [the issue template](https://raw.githubusercontent.com/archriss/react-native-snap-carousel/master/ISSUE_TEMPLATE.md) closely in order to produce a useful bug report.

<!--
  Please DO NOT go futher if you've not followed ALL of the above steps.
  Failing to do so will result in your issue getting closed without warning.
-->

### Have you made sure that it wasn't a [React Native bug](https://github.com/archriss/react-native-snap-carousel/issues?utf8=%E2%9C%93&q=is%3Aissue+label%3A%22react-native+bug%22+)?

(Write your answer here.)

<!--
  Steps you should take:

    1. Take a look at plugin's issues that are [labelled `react-native bug`](https://github.com/archriss/react-native-snap-carousel/issues?utf8=%E2%9C%93&q=is%3Aissue+label%3A%22react-native+bug%22+)

    2. Search [React Native issues](https://github.com/facebook/react-native/issues)

    3. Read the following sections of the doc again: ["Known issues"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/KNOWN_ISSUES.md), ["Important note regarding Android"](https://github.com/archriss/react-native-snap-carousel#important-note-regarding-android), and ["Custom interpolations caveats"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/CUSTOM_INTERPOLATIONS.md#caveats).
 -->

### Is the bug specific to iOS or Android? Or can it be reproduced on both platforms?

(Write your answer here and specify the iOS/Android versions on which you've been able to reproduce the issue.)

### Is the bug reproductible in a production environment (not a debug one)?

(Write your answer here.)

<!--
  If you haven't been able to reproduce the bug in production mode, it probably has to do with React Native's limitations (see ["Known issues"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/KNOWN_ISSUES.md)). Chances are we won't be able to do anything about it.
-->

### Environment

<!--
  Provide information about your current environment. At the very least, it should include the following:

  Environment:
    React: 16.0.0-beta.5
    React native: 0.49.2
    react-native-snap-carousel: 3.3.4

  Target Platform:
    Android (6.0)
    iOS (10.3)
-->

(Write your answer here.)

### Expected Behavior

<!--
  How did you expect your project to behave?
  It’s fine if you’re not sure your understanding is correct.
  Just write down what you thought would happen.
-->

(Write what you thought would happen.)

### Actual Behavior

<!--
  Did something go wrong?
  Is something broken, or not behaving as you expected?
  Describe this section in detail, and attach screencasts (or screenshots) if possible.
  Don't just say "it doesn't work"!
-->

(Write what happened. Add screencasts/screenshots!)

### Reproducible Demo

(Paste the link to a [Snack example](https://snack.expo.io/) in which the issue can be reproduced. Please follow [the guidelines](https://stackoverflow.com/help/mcve) for providing a Minimal, Complete, and Verifiable example.)

<!--
  This step is MANDATORY:

    * It shows that you value and respect the time of the people that are willing to help you; no one wishes to waste his spare time trying to recreate someone else's problem.
    * Issues without reproducible demos have an extremely low priority and will probably be closed without notice.
    * You might figure out the issues yourself as you work on extracting it.
-->

### Steps to Reproduce

<!--
  How would you describe your issue to someone who doesn’t know you or your project?
  Write a sequence of steps that anybody can repeat to see the issue.
  Be specific! If the bug cannot be reproduced, your issue will be closed.
-->

(Write your steps so that anyone can reproduce the issue in the Snack demo you provided.)

1.
2.
3.

<!--
  Thanks for helping us help you!
-->

==> react-native-snap-carousel-3.9.0.tgz: package/ISSUE_TEMPLATE.md <==
<!--
  MAKE SURE TO READ AND FOLLOW THIS TEMPLATE CLOSELY OR YOUR ISSUE WILL BE CLOSED WITHOUT NOTICE
-->

### Is this a bug report, a feature request, or a question?

(Write your answer here.)

<!--
  If you answered "Bug report":

    We expect you to produce a high-quality bug report since putting care into your report helps us fix the issue faster.
    For bug reports, it is REQUIRED to fill the rest of this template, or the issue will be closed.

  If you answered "Feature request" or "Question":

    Make sure to describe as precisely as possible the feature you'd like to see implemented or the question you'd like to see answered.
    When relevant, provide visual examples (screenshots, screencasts, diagrams...).
    You can ignore the next steps as long as you've made sure that your description is as clear, thorough and illustrated as possible.
-->

### Have you followed the required steps before opening a bug report?

(Check the step you've followed - put an `x` character between the square brackets (`[]`).)

- [] I have read [the guidelines regarding bug report](https://github.com/archriss/react-native-snap-carousel/blob/master/CONTRIBUTING.md).
- [] I have reviewed [the documentation](https://github.com/archriss/react-native-snap-carousel/blob/master/README.md) in its entirety, including the dedicated documentations :books:.
- [] I have searched for [existing issues](https://github.com/archriss/react-native-snap-carousel/issues) and made sure that the problem hasn't already been reported.
- [] I am using [the latest plugin version](https://github.com/archriss/react-native-snap-carousel/releases).
- [] I am following [the issue template](https://raw.githubusercontent.com/archriss/react-native-snap-carousel/master/ISSUE_TEMPLATE.md) closely in order to produce a useful bug report.

<!--
  Please DO NOT go futher if you've not followed ALL of the above steps.
  Failing to do so will result in your issue getting closed without warning.
-->

### Have you made sure that it wasn't a [React Native bug](https://github.com/archriss/react-native-snap-carousel/issues?utf8=%E2%9C%93&q=is%3Aissue+label%3A%22react-native+bug%22+)?

(Write your answer here.)

<!--
  Steps you should take:

    1. Take a look at plugin's issues that are [labelled `react-native bug`](https://github.com/archriss/react-native-snap-carousel/issues?utf8=%E2%9C%93&q=is%3Aissue+label%3A%22react-native+bug%22+)

    2. Search [React Native issues](https://github.com/facebook/react-native/issues)

    3. Read the following sections of the doc again: ["Known issues"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/KNOWN_ISSUES.md), ["Important note regarding Android"](https://github.com/archriss/react-native-snap-carousel#important-note-regarding-android), and ["Custom interpolations caveats"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/CUSTOM_INTERPOLATIONS.md#caveats).
 -->

### Is the bug specific to iOS or Android? Or can it be reproduced on both platforms?

(Write your answer here and specify the iOS/Android versions on which you've been able to reproduce the issue.)

### Is the bug reproductible in a production environment (not a debug one)?

(Write your answer here.)

<!--
  If you haven't been able to reproduce the bug in production mode, it probably has to do with React Native's limitations (see ["Known issues"](https://github.com/archriss/react-native-snap-carousel/blob/master/doc/KNOWN_ISSUES.md)). Chances are we won't be able to do anything about it.
-->

### Environment

<!--
  Provide information about your current environment. At the very least, it should include the following:

  Environment:
    React: 16.0.0-beta.5
    React native: 0.49.2
    react-native-snap-carousel: 3.3.4

  Target Platform:
    Android (6.0)
    iOS (10.3)
-->

(Write your answer here.)

### Expected Behavior

<!--
  How did you expect your project to behave?
  It’s fine if you’re not sure your understanding is correct.
  Just write down what you thought would happen.
-->

(Write what you thought would happen.)

### Actual Behavior

<!--
  Did something go wrong?
  Is something broken, or not behaving as you expected?
  Describe this section in detail, and attach screencasts (or screenshots) if possible.
  Don't just say "it doesn't work"!
-->

(Write what happened. Add screencasts/screenshots!)

### Reproducible Demo

(Paste the link to a [Snack example](https://snack.expo.io/) in which the issue can be reproduced. Please follow [the guidelines](https://stackoverflow.com/help/mcve) for providing a Minimal, Complete, and Verifiable example.)

<!--
  This step is MANDATORY:

    * It shows that you value and respect the time of the people that are willing to help you; no one wishes to waste his spare time trying to recreate someone else's problem.
    * Issues without reproducible demos have an extremely low priority and will probably be closed without notice.
    * You might figure out the issues yourself as you work on extracting it.
-->

### Steps to Reproduce

<!--
  How would you describe your issue to someone who doesn’t know you or your project?
  Write a sequence of steps that anybody can repeat to see the issue.
  Be specific! If the bug cannot be reproduced, your issue will be closed.
-->

(Write your steps so that anyone can reproduce the issue in the Snack demo you provided.)

1.
2.
3.

<!--
  Thanks for helping us help you!
-->
